@@ -1,4 +1,4 @@
-__version__ = 0.4
+__version__ = '0.5'
 __all__ = ['ColoredFormatter', 'CODES', 'DEFAULT_COLOR_LEVELS']
 
 import logging
@@ -42,18 +42,6 @@ class ColoredFormatter (logging.Formatter):
 	"""
 	A log record formatter providing color codes for terminal output,
 	by providing additional values to the format string.
-	
-	The codes are in the format ``fg_{colorname}`` or ``bg_{colorname}``
-	(foreground and background colors). Also provided are ``bold``
-	(for bold output), ``reset`` (to reset all formatting), and ``fg_level``
-	/ ``bg_level``, which return the color associated with the records level
-	(which is defined by either ``DEFAULT_COLOR_LEVELS`` or a user-provided
-	dict (``color_levels``) containing a mapping of level names to color names.
-
-	The colors names are ``black``, ``red``, ``green``, ``yellow``, ``blue``,
-	``purple``, ``cyan`` and ``white``.
-
-	A reset code is implictly appended to all messages unless ``reset == False``.
 	"""
 	
 	def __init__ (self, format, reset=False, color_levels=DEFAULT_COLOR_LEVELS):
